@@ -1,184 +1,196 @@
 test_that('sample sizes must be equal', {
   set.seed(123)
-  y <- rnorm(10)
   x <- rnorm(9)
+  y <- rnorm(10)
   expect_error(grpsel(x, y))
 })
 
 test_that('group must have ncol(x) elements', {
   set.seed(123)
-  y <- rnorm(10)
   x <- rnorm(10)
+  y <- rnorm(10)
   expect_error(grpsel(x, y, group = 1:11))
 })
 
 test_that('group (as a list) must have ncol(x) elements', {
   set.seed(123)
-  y <- rnorm(10)
   x <- rnorm(10)
+  y <- rnorm(10)
   expect_error(grpsel(x, y, group = list(1:5, 6:11)))
 })
 
 test_that('y must be in {0,1} with logistic loss', {
   set.seed(123)
+  x <- rnorm(10)
   y <- rbinom(10, 1, 0.5)
   y[y == 0] <- - 1
-  x <- rnorm(10)
   expect_error(grpsel(x, y, loss = 'logistic'))
 })
 
 test_that('y must not contain NAs', {
   set.seed(123)
-  y <- rnorm(10)
   x <- rnorm(10)
+  y <- rnorm(10)
   y[1] <- NA
   expect_error(grpsel(x, y))
 })
 
 test_that('x must not contain NAs', {
   set.seed(123)
-  y <- rnorm(10)
   x <- rnorm(10)
   x[1] <- NA
+  y <- rnorm(10)
   expect_error(grpsel(x, y))
 })
 
 test_that('lambda must contain a vector for every unique gamma', {
   set.seed(123)
-  y <- rnorm(10)
   x <- rnorm(10)
+  y <- rnorm(10)
   expect_error(grpsel(x, y, penalty = 'grSubset+grLasso', gamma = 1:5, lambda = 0))
 })
 
 test_that('lambda must contain ngamma vectors', {
   set.seed(123)
-  y <- rnorm(10)
   x <- rnorm(10)
+  y <- rnorm(10)
   expect_error(grpsel(x, y, penalty = 'grSubset+grLasso', ngamma = 5, lambda = 0))
 })
 
 test_that('nlambda must be greater than zero', {
   set.seed(123)
-  y <- rnorm(10)
   x <- rnorm(10)
+  y <- rnorm(10)
   expect_error(grpsel(x, y, nlambda = 0))
 })
 
 test_that('ngamma must be greater than zero', {
   set.seed(123)
-  y <- rnorm(10)
   x <- rnorm(10)
+  y <- rnorm(10)
   expect_error(grpsel(x, y, ngamma = 0))
 })
 
-test_that('alpha must be in (0,1)', {
+test_that('lambda.step must be in (0,1)', {
   set.seed(123)
-  y <- rnorm(10)
   x <- rnorm(10)
-  expect_error(grpsel(x, y, alpha = 1))
+  y <- rnorm(10)
+  expect_error(grpsel(x, y, lambda.step = 1))
 })
 
 test_that('when max.cd.iter is exceeded a warning is provided', {
   set.seed(123)
-  y <- rnorm(100)
   x <- matrix(rnorm(100 * 10), 100, 10)
-  expect_warning(grpsel(x, y, max.cd.iter = 5))
+  y <- rnorm(100)
+  expect_warning(grpsel(x, y, max.cd.iter = 0))
 })
 
 test_that('when max.ls.iter is exceeded a warning is provided', {
   set.seed(123)
-  y <- rnorm(100)
   x <- matrix(rnorm(100 * 10), 100, 10)
+  y <- rnorm(100)
   expect_warning(grpsel(x, y, max.ls.iter = 0))
 })
 
 test_that('gamma.min must be positive', {
   set.seed(123)
-  y <- rnorm(10)
   x <- rnorm(10)
+  y <- rnorm(10)
   expect_error(grpsel(x, y, gamma.min = 0))
 })
 
 test_that('gamma.max must be positive', {
   set.seed(123)
-  y <- rnorm(10)
   x <- rnorm(10)
+  y <- rnorm(10)
   expect_error(grpsel(x, y, gamma.max = 0))
 })
 
-test_that('subset.factor must have same length as group', {
+test_that('lambda.factor must have same length as group', {
   set.seed(123)
-  y <- rnorm(10)
   x <- rnorm(10)
-  expect_error(grpsel(x, y, subset.factor = rep(1, 11)))
+  y <- rnorm(10)
+  expect_error(grpsel(x, y, lambda.factor = rep(1, 11)))
 })
 
-test_that('lasso.factor must have same length as group', {
+test_that('gamma.factor must have same length as group', {
   set.seed(123)
-  y <- rnorm(10)
   x <- rnorm(10)
-  expect_error(grpsel(x, y, lasso.factor = rep(1, 11)))
+  y <- rnorm(10)
+  expect_error(grpsel(x, y, gamma.factor = rep(1, 11)))
 })
 
-test_that('ridge.factor must have same length as group', {
+test_that('maximum group size cannot exceed sample size when orthogonalising', {
   set.seed(123)
-  y <- rnorm(10)
-  x <- rnorm(10)
-  expect_error(grpsel(x, y, ridge.factor = rep(1, 11)))
+  group <- c(rep(1, 6), rep(2, 4))
+  x <- matrix(rnorm(5 * 10), 5, 10)
+  y <- rnorm(5)
+  expect_error(grpsel(x, y, group, orthogonalise = T))
 })
 
-test_that('regression with square loss works', {
+test_that('square loss regression works', {
   set.seed(123)
   group <- rep(1:5, each = 2)
   x <- matrix(rnorm(100 * 10), 100, 10)
   y <- rnorm(100)
-  fit <- grpsel(x, y, group, loss = 'square', eps = 1e-15)
+  fit <- grpsel(x, y, group, eps = 1e-15)
   beta <- coef(fit)[, ncol(coef(fit))]
-  beta.target <- as.numeric(glm(y ~ x, family = 'gaussian')$coef)
+  beta.target <- as.numeric(glm(y ~ x)$coef)
   expect_equal(beta, beta.target)
 })
 
-test_that('regression with logistic loss works', {
+test_that('logistic loss regression works', {
   set.seed(123)
   group <- rep(1:5, each = 2)
   x <- matrix(rnorm(100 * 10), 100, 10)
   y <- rbinom(100, 1, 0.5)
   fit <- grpsel(x, y, group, loss = 'logistic', eps = 1e-15)
   beta <- coef(fit)[, ncol(coef(fit))]
-  beta.target <- as.numeric(glm(y ~ x, family = 'binomial')$coef)
+  beta.target <- as.numeric(glm(y ~ x, 'binomial')$coef)
   expect_equal(beta, beta.target)
 })
 
-test_that('regression with different sized groups works', {
+test_that('different sized groups work', {
   set.seed(123)
   group <- c(1, 1, 1, 1, 2, 2, 2, 3, 3, 4)
   x <- matrix(rnorm(100 * 10), 100, 10)
   y <- rnorm(100)
-  fit <- grpsel(x, y, group, loss = 'square', eps = 1e-15)
+  fit <- grpsel(x, y, group, eps = 1e-15)
   beta <- coef(fit)[, ncol(coef(fit))]
-  beta.target <- as.numeric(glm(y ~ x, family = 'gaussian')$coef)
+  beta.target <- as.numeric(glm(y ~ x)$coef)
   expect_equal(beta, beta.target)
 })
 
-test_that('regression with overlapping groups works', {
+test_that('overlapping groups work', {
   set.seed(123)
   group <- list(1:5, 5:10)
   x <- matrix(rnorm(100 * 10), 100, 10)
   y <- rnorm(100)
-  fit <- grpsel(x, y, group, loss = 'square', eps = 1e-15)
+  fit <- grpsel(x, y, group, eps = 1e-15)
   beta <- coef(fit)[, ncol(coef(fit))]
-  beta.target <- as.numeric(glm(y ~ x, family = 'gaussian')$coef)
+  beta.target <- as.numeric(glm(y ~ x)$coef)
   expect_equal(beta, beta.target)
 })
 
-test_that('regression without orthogonalisation works', {
+test_that('orthogonalisation works', {
   set.seed(123)
-  group <- rep(1:5, each = 2)
+  group <- c(1, 2, 2, 2, 3, 3, 3, 4, 4, 4)
   x <- matrix(rnorm(100 * 10), 100, 10)
   y <- rnorm(100)
-  fit <- grpsel(x, y, group, loss = 'square', eps = 1e-15, orthogonalise = F)
+  fit <- grpsel(x, y, group, eps = 1e-15, orthogonalise = T)
   beta <- coef(fit)[, ncol(coef(fit))]
-  beta.target <- as.numeric(glm(y ~ x, family = 'gaussian')$coef)
+  beta.target <- as.numeric(glm(y ~ x)$coef)
+  expect_equal(beta, beta.target)
+})
+
+test_that('regression with overlapping groups and orthogonalisation works', {
+  set.seed(123)
+  group <- list(1:5, 5:10)
+  x <- matrix(rnorm(100 * 10), 100, 10)
+  y <- rnorm(100)
+  fit <- grpsel(x, y, group, orthogonalise = T, eps = 1e-15)
+  beta <- coef(fit)[, ncol(coef(fit))]
+  beta.target <- as.numeric(glm(y ~ x)$coef)
   expect_equal(beta, beta.target)
 })
 
@@ -187,9 +199,9 @@ test_that('regression without sorting works', {
   group <- rep(1:5, each = 2)
   x <- matrix(rnorm(100 * 10), 100, 10)
   y <- rnorm(100)
-  fit <- grpsel(x, y, group, loss = 'square', eps = 1e-15, sort = F)
+  fit <- grpsel(x, y, group, eps = 1e-15, sort = F)
   beta <- coef(fit)[, ncol(coef(fit))]
-  beta.target <- as.numeric(glm(y ~ x, family = 'gaussian')$coef)
+  beta.target <- as.numeric(glm(y ~ x)$coef)
   expect_equal(beta, beta.target)
 })
 
@@ -198,9 +210,9 @@ test_that('regression with screening works', {
   group <- rep(1:15, each = 2)
   x <- matrix(rnorm(100 * 30), 100, 30)
   y <- rnorm(100)
-  fit <- grpsel(x, y, group, loss = 'square', eps = 1e-15, screen = 5)
+  fit <- grpsel(x, y, group, eps = 1e-15, screen = 5)
   beta <- coef(fit)[, ncol(coef(fit))]
-  beta.target <- as.numeric(glm(y ~ x, family = 'gaussian')$coef)
+  beta.target <- as.numeric(glm(y ~ x)$coef)
   expect_equal(beta, beta.target)
 })
 
@@ -208,10 +220,10 @@ test_that('regression with screening and violations works', {
   set.seed(123)
   group <- rep(1:15, each = 2)
   x <- matrix(rnorm(100 * 30), 100, 30)
-  y <- rowSums(x) + rnorm(100)
-  fit <- grpsel(x, y, group, loss = 'square', eps = 1e-15, screen = 1)
+  y <- rnorm(100)
+  fit <- grpsel(x, y, group, eps = 1e-15, screen = 1)
   beta <- coef(fit)[, ncol(coef(fit))]
-  beta.target <- as.numeric(glm(y ~ x, family = 'gaussian')$coef)
+  beta.target <- as.numeric(glm(y ~ x)$coef)
   expect_equal(beta, beta.target)
 })
 
@@ -220,19 +232,18 @@ test_that('regression with a constant response works', {
   group <- rep(1:5, each = 2)
   x <- matrix(rnorm(100 * 10), 100, 10)
   y <- rep(1, 100)
-  fit <- grpsel(x, y, group, loss = 'square', eps = 1e-15)
+  fit <- grpsel(x, y, group, eps = 1e-15)
   beta <- coef(fit)[, ncol(coef(fit))]
-  beta.target <- as.numeric(glm(y ~ x, family = 'gaussian')$coef)
-  beta.target[2] <- 0
+  beta.target <- as.numeric(glm(y ~ x)$coef)
   expect_equal(beta, beta.target)
 })
 
 test_that('coefficients are extracted correctly', {
   set.seed(123)
   x <- matrix(rnorm(100 * 10), 100, 10)
-  y <- rowSums(x) + rnorm(100)
+  y <- rnorm(100)
   fit <- grpsel(x, y, eps = 1e-15)
-  fit.target <- glm(y ~ x, family = 'gaussian')
+  fit.target <- glm(y ~ x)
   beta <- coef(fit, lambda = 0)
   beta.target <- as.matrix(as.numeric(coef(fit.target)))
   expect_equal(beta, beta.target)
@@ -241,9 +252,9 @@ test_that('coefficients are extracted correctly', {
 test_that('predictions are computed correctly', {
   set.seed(123)
   x <- matrix(rnorm(100 * 10), 100, 10)
-  y <- rowSums(x) + rnorm(100)
+  y <- rnorm(100)
   fit <- grpsel(x, y, eps = 1e-15)
-  fit.target <- glm(y ~ x, family = 'gaussian')
+  fit.target <- glm(y ~ x)
   yhat <- predict(fit, x, lambda = 0)
   yhat.target <- as.matrix(as.numeric(predict(fit.target, as.data.frame(x))))
   expect_equal(yhat, yhat.target)
@@ -252,9 +263,9 @@ test_that('predictions are computed correctly', {
 test_that('predictions are computed correctly when x is a data frame', {
   set.seed(123)
   x <- matrix(rnorm(100 * 10), 100, 10)
-  y <- rowSums(x) + rnorm(100)
+  y <- rnorm(100)
   fit <- grpsel(x, y, eps = 1e-15)
-  fit.target <- glm(y ~ x, family = 'gaussian')
+  fit.target <- glm(y ~ x)
   yhat <- predict(fit, as.data.frame(x), lambda = 0)
   yhat.target <- as.matrix(as.numeric(predict(fit.target, as.data.frame(x))))
   expect_equal(yhat, yhat.target)
@@ -263,8 +274,8 @@ test_that('predictions are computed correctly when x is a data frame', {
 test_that('plot function returns a plot', {
   set.seed(123)
   x <- matrix(rnorm(100 * 10), 100, 10)
-  y <- rowSums(x) + rnorm(100)
-  fit <- grpsel(x, y, eps = 1e-15)
+  y <- rnorm(100)
+  fit <- grpsel(x, y)
   p <- plot(fit)
   expect_s3_class(p, 'ggplot')
 })
@@ -274,7 +285,7 @@ test_that('number of predictors does not exceed pmax', {
   group <- rep(1:5, each = 2)
   x <- matrix(rnorm(100 * 10), 100, 10)
   y <- rnorm(100)
-  fit <- grpsel(x, y, group, loss = 'square', eps = 1e-15, pmax = 5)
+  fit <- grpsel(x, y, group, pmax = 5)
   beta <- coef(fit)[, ncol(coef(fit))]
   sparsity <- sum(beta[- 1] != 0)
   expect_lte(sparsity, 5)
@@ -285,115 +296,112 @@ test_that('number of groups does not exceed gmax', {
   group <- rep(1:5, each = 2)
   x <- matrix(rnorm(100 * 10), 100, 10)
   y <- rnorm(100)
-  fit <- grpsel(x, y, group, loss = 'square', eps = 1e-15, gmax = 2)
+  fit <- grpsel(x, y, group, gmax = 2)
   beta <- coef(fit)[, ncol(coef(fit))]
   group.sparsity <- sum(vapply(unique(group), \(k) norm(beta[- 1][which(group == k)], '2'),
                                numeric(1)) != 0)
   expect_lte(group.sparsity, 2)
 })
 
-test_that('number of ridge solutions is ngamma', {
+test_that('number of ridge solutions is ngamma with square loss', {
   set.seed(123)
-  n <- 100
-  p <- 10
-  gamma <- 0.1
-  x <- matrix(rnorm(n * p), n, p)
-  y <- rnorm(n)
-  fit <- grpsel(x, y, penalty = 'grSubset+Ridge', ngamma = 5, lambda = rep(list(0), 5), eps = 1e-15)
+  x <- matrix(rnorm(100 * 10), 100, 10)
+  y <- rnorm(100)
+  fit <- grpsel(x, y, penalty = 'grSubset+Ridge', ngamma = 5, lambda = rep(list(0), 5))
   beta <- coef(fit)
   expect_equal(ncol(beta), 5)
 })
 
-test_that('number of group lasso solutions is ngamma', {
+test_that('number of ridge solutions is ngamma with logistic loss', {
   set.seed(123)
-  n <- 100
-  p <- 10
-  gamma <- 0.1
-  x <- matrix(rnorm(n * p), n, p)
-  y <- rnorm(n)
-  fit <- grpsel(x, y, penalty = 'grSubset+grLasso', ngamma = 5, lambda = rep(list(0), 5),
-                eps = 1e-15)
+  x <- matrix(rnorm(100 * 10), 100, 10)
+  y <- rbinom(100, 1, 0.5)
+  fit <- grpsel(x, y, penalty = 'grSubset+Ridge', loss = 'logistic', ngamma = 5,
+                lambda = rep(list(0), 5))
   beta <- coef(fit)
   expect_equal(ncol(beta), 5)
 })
 
-test_that('number of group lasso solutions is ngamma for logistic loss', {
+test_that('number of group lasso solutions is ngamma with square loss', {
   set.seed(123)
-  n <- 100
-  p <- 10
-  gamma <- 0.1
-  x <- matrix(rnorm(n * p), n, p)
-  y <- rbinom(n, 1, 0.5)
+  x <- matrix(rnorm(100 * 10), 100, 10)
+  y <- rnorm(100)
+  fit <- grpsel(x, y, penalty = 'grSubset+grLasso', ngamma = 5, lambda = rep(list(0), 5))
+  beta <- coef(fit)
+  expect_equal(ncol(beta), 5)
+})
+
+test_that('number of group lasso solutions is ngamma with logistic loss', {
+  set.seed(123)
+  x <- matrix(rnorm(100 * 10), 100, 10)
+  y <- rbinom(100, 1, 0.5)
   fit <- grpsel(x, y, penalty = 'grSubset+grLasso', loss = 'logistic', ngamma = 5,
-                lambda = rep(list(0), 5), eps = 1e-15)
+                lambda = rep(list(0), 5))
   beta <- coef(fit)
   expect_equal(ncol(beta), 5)
 })
 
-test_that('number of group lasso solutions is ngamma for logistic loss', {
+test_that('unpenalised group subset coefficients are always nonzero with logistic loss', {
   set.seed(123)
-  n <- 100
-  p <- 10
-  gamma <- 0.1
-  x <- matrix(rnorm(n * p), n, p)
-  y <- rbinom(n, 1, 0.5)
-  fit <- grpsel(x, y, penalty = 'grSubset+grLasso', loss = 'logistic', ngamma = 5,
-                lambda = rep(list(0), 5), lasso.factor = c(0, rep(1, 9)), eps = 1e-15)
+  x <- matrix(rnorm(100 * 10), 100, 10)
+  y <- rbinom(100, 1, 0.5)
+  fit <- grpsel(x, y,  loss = 'logistic', nlambda = 5, lambda.factor = c(0, rep(1, 9)))
   beta <- coef(fit)
-  expect_equal(ncol(beta), 5)
+  expect_equal(sum(beta[2, ] != 0), 5)
 })
 
-test_that('number of group lasso solutions is ngamma', {
+test_that('unpenalised group lasso coefficients are always nonzero with square loss', {
   set.seed(123)
-  n <- 100
-  p <- 10
-  gamma <- 0.1
-  x <- matrix(rnorm(n * p), n, p)
-  y <- rbinom(n, 1, 0.5)
+  x <- matrix(rnorm(100 * 10), 100, 10)
+  y <- rnorm(100)
   fit <- grpsel(x, y, penalty = 'grSubset+grLasso', ngamma = 5, lambda = rep(list(0), 5),
-                lasso.factor = c(0, rep(1, 9)), eps = 1e-15)
+                gamma.factor = c(0, rep(1, 9)))
   beta <- coef(fit)
-  expect_equal(ncol(beta), 5)
+  expect_equal(sum(beta[2, ] != 0), 5)
 })
 
-test_that('local search improves on coordinate descent for logistic loss', {
+test_that('unpenalised group lasso coefficients are always with logistic loss', {
   set.seed(123)
-  n <- 100
-  p <- 50
-  group <- rep(1:25, each = 2)
-  x <- matrix(rnorm(n * p), n, p) + 2 * matrix(rnorm(n), n, p)
-  y <- rbinom(n, 1, 1 / (1 + exp(- rowSums(x[, 1:10]))))
-  fit.ls <- grpsel(x, y, group, loss = 'logistic', ls = T)
-  fit.cd <- grpsel(x, y, group, loss = 'logistic', ls = F)
-  loss.ls <- fit.ls$loss[[1]][which(fit.ls$np[[1]] %in% fit.cd$np[[1]])]
-  loss.cd <- fit.cd$loss[[1]][which(fit.cd$np[[1]] %in% fit.ls$np[[1]])]
-  expect_true(sum(loss.ls) < sum(loss.cd))
+  x <- matrix(rnorm(100 * 10), 100, 10)
+  y <- rbinom(100, 1, 0.5)
+  fit <- grpsel(x, y, penalty = 'grSubset+grLasso', loss = 'logistic', ngamma = 5,
+                lambda = rep(list(0), 5), gamma.factor = c(0, rep(1, 9)))
+  beta <- coef(fit)
+  expect_equal(sum(beta[2, ] != 0), 5)
 })
 
 test_that('local search improves on coordinate descent for square loss', {
   set.seed(123)
-  n <- 100
-  p <- 50
-  group <- rep(1:25, each = 2)
-  x <- matrix(rnorm(n * p), n, p) + 2 * matrix(rnorm(n), n, p)
-  y <- rnorm(n, rowSums(x[, 1:10]))
-  fit.ls <- grpsel(x, y, group, loss = 'square', ls = T)
-  fit.cd <- grpsel(x, y, group, loss = 'square', ls = F)
-  loss.ls <- fit.ls$loss[[1]][which(fit.ls$np[[1]] %in% fit.cd$np[[1]])]
-  loss.cd <- fit.cd$loss[[1]][which(fit.cd$np[[1]] %in% fit.ls$np[[1]])]
+  group <- rep(1:10, each = 2)
+  x <- matrix(rnorm(100 * 20), 100, 20) + matrix(rnorm(100), 100, 20)
+  y <- rnorm(100, rowSums(x[, 1:10]))
+  fit.ls <- grpsel(x, y, group, local.search = T)
+  fit.cd <- grpsel(x, y, group)
+  loss.ls <- fit.ls$loss[[1]][fit.ls$np[[1]] %in% fit.cd$np[[1]]]
+  loss.cd <- fit.cd$loss[[1]][fit.cd$np[[1]] %in% fit.ls$np[[1]]]
   expect_true(sum(loss.ls) < sum(loss.cd))
 })
 
-test_that('local search improves on coordinate descent for square loss without orthogonalisation', {
+test_that('local search improves on coordinate descent for square loss with orthogonalisation', {
   set.seed(123)
-  n <- 100
-  p <- 50
-  group <- rep(1:25, each = 2)
-  x <- matrix(rnorm(n * p), n, p) + 2 * matrix(rnorm(n), n, p)
-  y <- rnorm(n, rowSums(x[, 1:10]))
-  fit.ls <- grpsel(x, y, group, loss = 'square', ls = T, orthogonalise = F)
-  fit.cd <- grpsel(x, y, group, loss = 'square', ls = F, orthogonalise = F)
-  loss.ls <- fit.ls$loss[[1]][which(fit.ls$np[[1]] %in% fit.cd$np[[1]])]
-  loss.cd <- fit.cd$loss[[1]][which(fit.cd$np[[1]] %in% fit.ls$np[[1]])]
+  group <- rep(1:10, each = 2)
+  x <- matrix(rnorm(100 * 20), 100, 20) + matrix(rnorm(100), 100, 20)
+  y <- rnorm(100, rowSums(x[, 1:10]))
+  fit.ls <- grpsel(x, y, group, local.search = T, orthogonalise = T)
+  fit.cd <- grpsel(x, y, group, orthogonalise = T)
+  loss.ls <- fit.ls$loss[[1]][fit.ls$np[[1]] %in% fit.cd$np[[1]]]
+  loss.cd <- fit.cd$loss[[1]][fit.cd$np[[1]] %in% fit.ls$np[[1]]]
+  expect_true(sum(loss.ls) < sum(loss.cd))
+})
+
+test_that('local search improves on coordinate descent for logistic loss', {
+  set.seed(123)
+  group <- rep(1:10, each = 2)
+  x <- matrix(rnorm(100 * 20), 100, 20) + matrix(rnorm(100), 100, 20)
+  y <- rbinom(100, 1, 1 / (1 + exp(- rowSums(x[, 1:10]))))
+  fit.ls <- grpsel(x, y, group, loss = 'logistic', local.search = T)
+  fit.cd <- grpsel(x, y, group, loss = 'logistic')
+  loss.ls <- fit.ls$loss[[1]][fit.ls$np[[1]] %in% fit.cd$np[[1]]]
+  loss.cd <- fit.cd$loss[[1]][fit.cd$np[[1]] %in% fit.ls$np[[1]]]
   expect_true(sum(loss.ls) < sum(loss.cd))
 })
